@@ -19,12 +19,47 @@ from . import genome_registry
 from .logger import logger
 from .cbedtools import create_interval_from_list
 
-
 BUFSIZE = 1
 
 _tags = {}
 
 
+def set_bedtools_path(path=""):
+    """
+    Explicitly set path to `BEDTools` installation dir.
+
+    If BEDTools is not available on your system path, specify the path to the
+    dir containing the BEDTools executables (intersectBed, subtractBed, etc)
+    with this function.
+
+    To reset and use the default system path, call this function with no
+    arguments or use path="".
+    """
+    from . import paths
+    paths._set_bedtools_path(path)
+
+
+def get_bedtools_path():
+    """
+    Returns the currently-set path to bedtools
+    """
+    from . import paths
+    return paths._get_bedtools_path()
+
+
+def set_R_path(path=""):
+    """
+    Explicitly set path to `R` installation dir.
+
+    If R is not available on the path, then it can be explicitly
+    specified here.
+
+    Use path="" to reset to default system path.
+    """
+    from . import paths
+    paths._set_R_path(path)
+
+
 def _check_for_bedtools(program_to_check='intersectBed', force_check=False):
     """
     Checks installation as well as version (based on whether or not "bedtools
@@ -33,33 +68,72 @@ def _check_for_bedtools(program_to_check='intersectBed', force_check=False):
     if settings._bedtools_installed and not force_check:
         return True
 
-    try:
-        p = subprocess.Popen(
-            [os.path.join(settings._bedtools_path, 'bedtools'),
-             settings._prog_names[program_to_check]],
-            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        settings._bedtools_installed = True
-        settings._v_2_15_plus = True
-
-    except (OSError, KeyError) as err:
-
+    if len(settings.bedtools_version) == 0:
+        # let us quickly determine the program version by calling without
+        # specifying application
         try:
-            p = subprocess.Popen(
-                [os.path.join(settings._bedtools_path, program_to_check)],
-                stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            v = subprocess.check_output(
+                [
+                    os.path.join(
+                        settings._bedtools_path, 'bedtools'),
+                    '--version'])
+
             settings._bedtools_installed = True
-            settings._v_2_15_plus = False
 
-        except OSError as err:
-            if err.errno == 2:
-                if settings._bedtools_path:
-                    add_msg = "(tried path '%s')" % settings._bedtools_path
-                else:
-                    add_msg = ""
-                raise OSError("Please make sure you have installed BEDTools"
-                              "(https://github.com/arq5x/bedtools) and that "
-                              "it's on the path. %s" % add_msg)
+            # e.g.,
+            #
+            #  bedtools v2.26.0
+            #
+            vv = v.decode().split('v')[1]
 
+            settings.bedtools_version = [int(i) for i in vv.split(".")]
+
+            settings._v_2_27_plus = (
+                settings.bedtools_version[0] >= 2 and
+                settings.bedtools_version[1] >= 27
+            )
+
+            settings._v_2_15_plus = (
+                settings.bedtools_version[0] >= 2 and
+                settings.bedtools_version[1] >= 15
+            )
+
+        except subprocess.CalledProcessError:
+            if settings._bedtools_path:
+                add_msg = "(tried path '%s')" % settings._bedtools_path
+            else:
+                add_msg = ""
+            raise OSError("Please make sure you have installed BEDTools"
+                          "(https://github.com/arq5x/bedtools) and that "
+                          "it's on the path. %s" % add_msg)
+
+    # Disabling the additional pre-2.15 check since the above code is now
+    # handling it based on what --version reports.
+    #
+    # TODO: fully deprecate this, and eventually remove v2.15 support.
+    #
+    # try:
+    #     p = subprocess.Popen(
+    #         [os.path.join(settings._bedtools_path, 'bedtools'),
+    #          settings._prog_names[program_to_check]],
+    #         stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    #     settings._bedtools_installed = True
+    #     settings._v_2_15_plus = True
+    #     settings._v_2_27_plus = False
+
+    # except (OSError, KeyError) as err:
+    #     try:
+    #         p = subprocess.Popen(
+    #             [os.path.join(settings._bedtools_path, program_to_check)],
+    #             stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    #         settings._bedtools_installed = True
+    #         settings._v_2_15_plus = False
+
+    #     except OSError as err:
+    #         if err.errno == 2:
+    #             raise OSError("BEDTools exists as a binary but seems otherwise incompatible. "
+    #                           "Please check that what is installed in '%s' is indeed from "
+    #                           "https://github.com/arq5x/bedtools." % settings._bedtools_path)
 
 def _check_for_R():
     try:
@@ -104,7 +178,9 @@ def isBGZIP(fn):
     """
     Reads a filename to see if it's a BGZIPed file or not.
     """
-    header_str = open(fn, 'rb').read(15)
+    with open(fn, 'rb') as fh:
+        header_str = fh.read(15)
+
     if len(header_str) < 15:
         return False
 
@@ -170,7 +246,9 @@ def set_tempdir(tempdir):
     """
     if not os.path.exists(tempdir):
         errstr = 'The tempdir you specified, %s, does not exist' % tempdir
-        raise ValueError(errstr)
+        if six.PY2:
+            raise ValueError(errstr)
+        raise FileNotFoundError(errstr)
     tempfile.tempdir = tempdir
 
 
@@ -383,32 +461,6 @@ def call_bedtools(cmds, tmpfn=None, stdin=None, check_stderr=None, decode_output
     return output
 
 
-def set_bedtools_path(path=""):
-    """
-    Explicitly set path to `BEDTools` installation dir.
-
-    If BEDTools is not available on your system path, specify the path to the
-    dir containing the BEDTools executables (intersectBed, subtractBed, etc)
-    with this function.
-
-    To reset and use the default system path, call this function with no
-    arguments or use path="".
-    """
-    settings._bedtools_path = path
-
-
-def set_R_path(path=""):
-    """
-    Explicitly set path to `R` installation dir.
-
-    If R is not available on the path, then it can be explicitly
-    specified here.
-
-    Use path="" to reset to default system path.
-    """
-    settings._R_path = path
-
-
 def _check_sequence_stderr(x):
     """
     If stderr created by fastaFromBed starts with 'index file', then don't
@@ -558,6 +610,45 @@ class FisherOutput(object):
         return '<%s at %s>\n%s' % (self.__class__.__name__, id(self), self.text)
 
 
+class SplitOutput(object):
+    def __init__(self, output, **kwargs):
+        """
+        Handles output from bedtools split, which sends a report of files to
+        stdout. This class parses that list into something more convenient to
+        use within pybedtools.
+
+        Most useful is probably the .bedtools attribute, which is a list of
+        BedTool objects.
+        """
+        from .bedtool import BedTool
+
+        if isinstance(output, str):
+            output = open(output).read()
+        if hasattr(output, 'next'):
+            output = ''.join(i for i in output)
+
+        #: store a copy of the output
+        self.text = output
+
+        #: BedTool objects created from output
+        self.bedtools = []
+
+        #: Filenames that were created from the split
+        self.files = []
+
+        #: number of bases in each file
+        self.nbases = []
+
+        #: number of features in each file
+        self.counts = []
+
+        for line in output.splitlines():
+            toks = line.split()
+            self.files.append(toks[0])
+            self.nbases.append(int(toks[1]))
+            self.counts.append(int(toks[2]))
+            self.bedtools.append(BedTool(toks[0]))
+
 
 def internet_on(timeout=1):
     try:
@@ -568,38 +659,25 @@ def internet_on(timeout=1):
     return False
 
 
-def get_chromsizes_from_ucsc(genome, saveas=None, mysql='mysql', timeout=None):
+def get_chromsizes_from_ucsc(genome, saveas=None, mysql='mysql',
+                             fetchchromsizes='fetchChromSizes', timeout=None):
     """
     Download chrom size info for *genome* from UCSC and returns the dictionary.
 
-    If you need the file, then specify a filename with *saveas* (the dictionary
-    will still be returned as well).
+    Parameters
+    ----------
 
-    If ``mysql`` is not on your path, specify where to find it with
-    *mysql=<path to mysql executable>*.
+    genome : str
+        Name of the genome assembly (e.g., "hg38")
 
-    *timeout* is how long to wait for a response; mostly used for testing.
+    saveas : str
+        Filename to save output to. Dictionary will still be returned.
 
-    Example usage:
+    mysql, fetchchromsizes : str
+        Paths to MySQL and fetchChromSizes.
 
-        >>> dm3_chromsizes = get_chromsizes_from_ucsc('dm3')
-        >>> for i in sorted(dm3_chromsizes.items()):
-        ...     print('{0}: {1}'.format(*i))
-        chr2L: (0, 23011544)
-        chr2LHet: (0, 368872)
-        chr2R: (0, 21146708)
-        chr2RHet: (0, 3288761)
-        chr3L: (0, 24543557)
-        chr3LHet: (0, 2555491)
-        chr3R: (0, 27905053)
-        chr3RHet: (0, 2517507)
-        chr4: (0, 1351857)
-        chrM: (0, 19517)
-        chrU: (0, 10049037)
-        chrUextra: (0, 29004656)
-        chrX: (0, 22422827)
-        chrXHet: (0, 204112)
-        chrYHet: (0, 347038)
+    timeout : float
+        How long to wait for a response; mostly used for testing.
 
     """
     if not internet_on(timeout=timeout):
@@ -611,6 +689,8 @@ def get_chromsizes_from_ucsc(genome, saveas=None, mysql='mysql', timeout=None):
             '-A',
             '-e',
             'select chrom, size from %s.chromInfo' % genome]
+    failures = []
+    d = {}
     try:
         p = subprocess.Popen(cmds,
                              stdout=subprocess.PIPE,
@@ -623,7 +703,6 @@ def get_chromsizes_from_ucsc(genome, saveas=None, mysql='mysql', timeout=None):
             print((subprocess.list2cmdline(cmds)))
 
         lines = stdout.splitlines()[1:]
-        d = {}
         for line in lines:
             if isinstance(line, bytes):
                 line = line.decode('UTF-8')
@@ -633,16 +712,42 @@ def get_chromsizes_from_ucsc(genome, saveas=None, mysql='mysql', timeout=None):
         if saveas is not None:
             chromsizes_to_file(d, saveas)
 
-        return d
 
     except OSError as err:
         if err.errno == 2:
-            raise OSError("Can't find mysql -- if you don't have it "
-                          "installed, you'll have to get chromsizes "
-                          " manually, or "
-                          "specify the path with the 'mysql' kwarg.")
+            failures.append("Can't find mysql at path {0}".format(mysql))
         else:
             raise
+    try:
+        cmds = [fetchchromsizes, genome]
+        p = subprocess.Popen(cmds,
+                             stdout=subprocess.PIPE,
+                             stderr=subprocess.PIPE,
+                             bufsize=1)
+        stdout, stderr = p.communicate()
+        if stderr:
+            if 'INFO: trying WGET' not in str(stderr):
+                print(stderr)
+                print('Commands were:\n')
+                print((subprocess.list2cmdline(cmds)))
+
+        lines = stdout.splitlines()
+        for line in lines:
+            if isinstance(line, bytes):
+                line = line.decode('UTF-8')
+            chrom, size = line.split()
+            d[chrom] = (0, int(size))
+
+        if saveas is not None:
+            chromsizes_to_file(d, saveas)
+
+    except OSError as err:
+        if err.errno == 2:
+            failures.append("Can't find path to fetchChromsizes")
+
+    if not d:
+        raise OSError(failures)
+    return d
 
 
 def chromsizes_to_file(chrom_sizes, fn=None):
@@ -706,4 +811,16 @@ def chromsizes(genome):
     except AttributeError:
         return get_chromsizes_from_ucsc(genome)
 
+def get_includes():
+    """
+    Returns a list of include directories with BEDTools headers
+    """
+    dirname = os.path.abspath(os.path.join(os.path.dirname(__file__)))
+    return [
+        dirname,
+        os.path.join(dirname, 'include')
+    ]
+
+
 atexit.register(cleanup)
+
