@@ -4,12 +4,13 @@ _R_path = ""
 tempfile_prefix = 'pybedtools.'
 tempfile_suffix = '.tmp'
 
-
 # Checking for BEDTools will happen when creating the first BedTool; other
 # checks happen at first use (BAM object creation; tabix-ing a BedTool)
 _bedtools_installed = False
 _R_installed = False
 _v_2_15_plus = False
+_v_2_27_plus = False
+bedtools_version = []
 
 KEEP_TEMPFILES = False
 _DEBUG = True
@@ -37,6 +38,7 @@ _prog_names = {
     'randomBed': 'random',
     'shuffleBed': 'shuffle',
     'annotateBed': 'annotate',
+    'spacing': 'spacing',
 
     # multi-way
     'multiIntersectBed': 'multiinter',
@@ -75,6 +77,8 @@ _prog_names = {
     'expandCols': 'expand',
     'sample': 'sample',
     'fisher': 'fisher',
+
+    'split': 'split',
 }
 
 _old_names = list(_prog_names.keys())
